summaryrefslogtreecommitdiff
path: root/t/test-custodian-parser.rb
diff options
context:
space:
mode:
Diffstat (limited to 't/test-custodian-parser.rb')
-rwxr-xr-xt/test-custodian-parser.rb8
1 files changed, 7 insertions, 1 deletions
diff --git a/t/test-custodian-parser.rb b/t/test-custodian-parser.rb
index 1448a1d..1a5be6e 100755
--- a/t/test-custodian-parser.rb
+++ b/t/test-custodian-parser.rb
@@ -68,7 +68,13 @@ class TestCustodianParser < Test::Unit::TestCase
result = parser.parse_line( "# this is a comment" )
assert( result.nil? )
- # 1.b. Adding a test will return an array of test-objects.
+ # 1.b. Non-strings are an error
+ assert_raise ArgumentError do
+ result = parser.parse_line( nil )
+ end
+
+
+ # 1.c. Adding a test will return an array of test-objects.
result = parser.parse_line( "smtp.bytemark.co.uk must run smtp on 25 otherwise 'failure'." );
assert( !result.nil? )
assert( result.kind_of? Array )